@@ -1,12 +1,11 @@
 package app
 
 import (
-	"context"
 	_ "embed"
 
 	"github.com/livebud/bud/framework"
+	"github.com/livebud/bud/package/budfs"
 	"github.com/livebud/bud/package/di"
-	"github.com/livebud/bud/package/overlay"
 
 	"github.com/livebud/bud/internal/gotemplate"
 	"github.com/livebud/bud/package/gomod"
@@ -31,7 +30,7 @@ type Generator struct {
 	module   *gomod.Module
 }
 
-func (g *Generator) GenerateFile(ctx context.Context, fsys overlay.F, file *overlay.File) error {
+func (g *Generator) GenerateFile(fsys budfs.FS, file *budfs.File) error {
 	state, err := Load(fsys, g.injector, g.module, g.flag)
 	if err != nil {
 		return err
