@@ -3,13 +3,13 @@ package controller
 import (
 
 	// Embed templates
-	"context"
+
 	_ "embed"
 
 	"github.com/livebud/bud/internal/gotemplate"
+	"github.com/livebud/bud/package/budfs"
 	"github.com/livebud/bud/package/di"
 	"github.com/livebud/bud/package/gomod"
-	"github.com/livebud/bud/package/overlay"
 	"github.com/livebud/bud/package/parser"
 )
 
@@ -35,7 +35,7 @@ type Generator struct {
 	parser   *parser.Parser
 }
 
-func (g *Generator) GenerateFile(ctx context.Context, fsys overlay.F, file *overlay.File) error {
+func (g *Generator) GenerateFile(fsys budfs.FS, file *budfs.File) error {
 	state, err := Load(fsys, g.injector, g.module, g.parser)
 	if err != nil {
 		return err
