@@ -1,12 +1,11 @@
 package web
 
 import (
-	"context"
 	_ "embed"
 
 	"github.com/livebud/bud/internal/gotemplate"
+	"github.com/livebud/bud/package/budfs"
 	"github.com/livebud/bud/package/gomod"
-	"github.com/livebud/bud/package/overlay"
 	"github.com/livebud/bud/package/parser"
 )
 
@@ -29,7 +28,7 @@ type Generator struct {
 	parser *parser.Parser
 }
 
-func (g *Generator) GenerateFile(ctx context.Context, fsys overlay.F, file *overlay.File) error {
+func (g *Generator) GenerateFile(fsys budfs.FS, file *budfs.File) error {
 	state, err := Load(fsys, g.module, g.parser)
 	if err != nil {
 		return err
