@@ -35,12 +35,12 @@ func (c *Command) Run(ctx context.Context) error {
 	if err != nil {
 		return err
 	}
-	fsys, close, err := bud.FileSystem(ctx, log, module, c.Flag, c.in)
+	bfs, err := bud.FileSystem(ctx, log, module, c.Flag, c.in)
 	if err != nil {
 		return err
 	}
-	defer close()
-	code, err := fs.ReadFile(fsys, path.Clean(c.Path))
+	defer bfs.Close()
+	code, err := fs.ReadFile(bfs, path.Clean(c.Path))
 	if err != nil {
 		return err
 	}
