@@ -13,11 +13,9 @@ func TestMap(t *testing.T) {
 	is := is.New(t)
 	fsys := virtual.Map{
 		"bud/view/index.svelte": &virtual.File{
-			Path: "bud/view/index.svelte",
 			Data: []byte(`<h1>index</h1>`),
 		},
 		"bud/view/about/index.svelte": &virtual.File{
-			Path: "bud/view/about/index.svelte",
 			Data: []byte(`<h1>about</h1>`),
 		},
 	}
@@ -33,7 +31,7 @@ func TestMap(t *testing.T) {
 	is.Equal(string(code), `<h1>about</h1>`)
 
 	// Remove bud/view/index.svelte
-	err = fsys.Remove("bud/view/index.svelte")
+	err = fsys.RemoveAll("bud/view/index.svelte")
 	is.NoErr(err)
 
 	// Read bud/view/index.svelte
@@ -47,12 +45,12 @@ func TestMapWriteRead(t *testing.T) {
 	fsys := virtual.Map{}
 
 	// Create a directory
-	err := fsys.Mkdir("a/b", 0755)
+	err := fsys.MkdirAll("a/b", 0755)
 	is.NoErr(err)
 	stat, err := fs.Stat(fsys, "a/b")
 	is.NoErr(err)
 	is.Equal(stat.Name(), "b")
-	is.Equal(stat.IsDir(), true)
+	is.Equal(stat.IsDir(), true, "a/b should be a directory")
 
 	// Write a file
 	err = fsys.WriteFile("a/b/c.txt", []byte("c"), 0644)
@@ -61,3 +59,17 @@ func TestMapWriteRead(t *testing.T) {
 	is.NoErr(err)
 	is.Equal(string(code), `c`)
 }
+
+func TestMapRoot(t *testing.T) {
+	is := is.New(t)
+	fsys := virtual.Map{}
+	des, err := fs.ReadDir(fsys, ".")
+	is.True(errors.Is(err, fs.ErrNotExist))
+	is.Equal(des, nil)
+	fsys = virtual.Map{
+		".": &virtual.File{Mode: fs.ModeDir},
+	}
+	des, err = fs.ReadDir(fsys, ".")
+	is.NoErr(err)
+	is.Equal(len(des), 0)
+}
